# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------
from azure.mgmt.synapse.models import AzureADOnlyAuthentication


def synapse_enable_adonly_auth(client, resource_group_name, workspace_name):
    azure_ad_only_authentication_name = "default"
    azure_ad_only_authentication_info = AzureADOnlyAuthentication(azure_ad_only_authentication=True)

    return client.begin_create(resource_group_name, workspace_name,
                               azure_ad_only_authentication_name, azure_ad_only_authentication_info)


def synapse_disable_adonly_auth(client, resource_group_name, workspace_name):
    azure_ad_only_authentication_name = "default"
    azure_ad_only_authentication_info = AzureADOnlyAuthentication(azure_ad_only_authentication=False)

    return client.begin_create(resource_group_name, workspace_name,
                               azure_ad_only_authentication_name, azure_ad_only_authentication_info)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from enum import Enum


class Symbol(Enum):
    WHITE_SPACE = " "
    QUOTE = '"'
    COLON = ":"
    LEFT_SQUARE_BRACKET = "["
    RIGHT_SQUARE_BRACKET = "]"
    DOT = "."
    EQUAL = "="
    ASTERISK = "*"
    PLUS = "+"
    MINUS = "-"
    TILDE = "~"
    EXCLAMATION_POINT = "!"
    CROSS = "x"

    def __str__(self):
        return self.value



# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------
# pylint: disable=too-many-statements
# pylint: disable=too-many-locals

from azure.cli.core.commands import CliCommandType


def load_command_table(self, _):

    from ..generated._client_factory import cf_device
    databoxedge_device = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._devices_operations#DevicesOperations.{}',
        client_factory=cf_device)
    with self.command_group('databoxedge device', databoxedge_device, client_factory=cf_device,
                            min_api='2019-08-01') as g:
        g.custom_command('list', 'databoxedge_device_list')
        g.custom_show_command('show', 'databoxedge_device_show')
        g.custom_command('create', 'databoxedge_device_create', supports_no_wait=True)
        g.custom_command('update', 'databoxedge_device_update')
        g.custom_command('delete', 'databoxedge_device_delete', supports_no_wait=True, confirmation=True)
        g.custom_command('download-update', 'databoxedge_device_download_update', supports_no_wait=True)
        g.custom_command('install-update', 'databoxedge_device_install_update', supports_no_wait=True)
        g.custom_command('scan-for-update', 'databoxedge_device_scan_for_update', supports_no_wait=True)
        g.custom_command('show-update-summary', 'databoxedge_device_show_update_summary')
        g.custom_wait_command('wait', 'databoxedge_device_show')

    from ..generated._client_factory import cf_alert
    databoxedge_alert = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._alerts_operations#AlertsOperations.{}',
        client_factory=cf_alert)
    with self.command_group('databoxedge alert', databoxedge_alert, client_factory=cf_alert,
                            min_api='2019-08-01') as g:
        g.custom_command('list', 'databoxedge_alert_list')
        g.custom_show_command('show', 'databoxedge_alert_show')

    from ..generated._client_factory import cf_bandwidth_schedule
    databoxedge_bandwidth_schedule = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._bandwidth_schedules_operations#BandwidthSchedulesOperations'
        '.{}',
        client_factory=cf_bandwidth_schedule)
    with self.command_group('databoxedge bandwidth-schedule', databoxedge_bandwidth_schedule,
                            client_factory=cf_bandwidth_schedule, min_api='2019-08-01') as g:
        g.custom_command('list', 'databoxedge_bandwidth_schedule_list')
        g.custom_show_command('show', 'databoxedge_bandwidth_schedule_show')
        g.custom_command('create', 'databoxedge_bandwidth_schedule_create', supports_no_wait=True)
        g.generic_update_command('update', custom_func_name='databoxedge_bandwidth_schedule_update',
                                 supports_no_wait=True)
        g.custom_command('delete', 'databoxedge_bandwidth_schedule_delete', supports_no_wait=True, confirmation=True)
        g.custom_wait_command('wait', 'databoxedge_bandwidth_schedule_show')

    from ..generated._client_factory import cf_job
    databoxedge_job = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._jobs_operations#JobsOperations.{}',
        client_factory=cf_job)
    with self.command_group('databoxedge', databoxedge_job, client_factory=cf_job, is_preview=True,
                            min_api='2019-08-01') as g:
        g.custom_command('show-job', 'databoxedge_show_job')

    from ..generated._client_factory import cf_node
    databoxedge_node = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._nodes_operations#NodesOperations.{}',
        client_factory=cf_node)
    with self.command_group('databoxedge', databoxedge_node, client_factory=cf_node, is_preview=True,
                            min_api='2019-08-01') as g:
        g.custom_command('list-node', 'databoxedge_list_node')

    from ..generated._client_factory import cf_order
    databoxedge_order = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._orders_operations#OrdersOperations.{}',
        client_factory=cf_order)
    with self.command_group('databoxedge order', databoxedge_order, client_factory=cf_order,
                            min_api='2019-08-01') as g:
        g.custom_command('list', 'databoxedge_order_list')
        g.custom_show_command('show', 'databoxedge_order_show')
        g.custom_command('create', 'databoxedge_order_create', supports_no_wait=True)
        g.generic_update_command('update', setter_arg_name='order', custom_func_name='databoxedge_order_update',
                                 supports_no_wait=True)
        g.custom_command('delete', 'databoxedge_order_delete', supports_no_wait=True, confirmation=True)
        g.custom_wait_command('wait', 'databoxedge_order_show')

    from ..generated._client_factory import cf_sku
    databoxedge_sku = CliCommandType(
        operations_tmpl='azure.mgmt.databoxedge.operations._skus_operations#SkusOperations.{}',
        client_factory=cf_sku)
    with self.command_group('databoxedge', databoxedge_sku, client_factory=cf_sku, is_preview=True,
                            min_api='2019-08-01') as g:
        g.custom_command('list-sku', 'databoxedge_list_sku')



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.util import CLIError


def consumption_exception_handler(ex):
    from azure.mgmt.consumption.models import ErrorResponseException
    if isinstance(ex, ErrorResponseException):
        message = ex.message
        raise CLIError(message)
    raise ex



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.util import CLIError


class HttpResponseValidator:  # pylint:disable=too-few-public-methods

    @staticmethod
    def check_response_status(response, expected_code=None):
        expected_code = expected_code or 200
        if response.status_code != expected_code:
            raise CLIError('Failed with status code {} and reason {}'.format(
                response.status_code, response.text))



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
#
# Code generated by aaz-dev-tools
# --------------------------------------------------------------------------------------------

# pylint: skip-file
# flake8: noqa

from azure.cli.core.aaz import *


@register_command(
    "monitor log-analytics cluster list",
)
class List(AAZCommand):
    """List all cluster instances in a resource group or in current subscription.

    :example: List all cluster instances in a resource group.
        az monitor log-analytics cluster list -g MyResourceGroup

    :example: List all cluster instances in current subscription.
        az monitor log-analytics cluster list
    """

    _aaz_info = {
        "version": "2021-06-01",
        "resources": [
            ["mgmt-plane", "/subscriptions/{}/providers/microsoft.operationalinsights/clusters", "2021-06-01"],
            ["mgmt-plane", "/subscriptions/{}/resourcegroups/{}/providers/microsoft.operationalinsights/clusters", "2021-06-01"],
        ]
    }

    def _handler(self, command_args):
        super()._handler(command_args)
        return self.build_paging(self._execute_operations, self._output)

    _args_schema = None

    @classmethod
    def _build_arguments_schema(cls, *args, **kwargs):
        if cls._args_schema is not None:
            return cls._args_schema
        cls._args_schema = super()._build_arguments_schema(*args, **kwargs)

        # define Arg Group ""

        _args_schema = cls._args_schema
        _args_schema.resource_group = AAZResourceGroupNameArg()
        return cls._args_schema

    def _execute_operations(self):
        self.pre_operations()
        condition_0 = has_value(self.ctx.args.resource_group) and has_value(self.ctx.subscription_id)
        condition_1 = has_value(self.ctx.subscription_id) and has_value(self.ctx.args.resource_group) is not True
        if condition_0:
            self.ClustersListByResourceGroup(ctx=self.ctx)()
        if condition_1:
            self.ClustersList(ctx=self.ctx)()
        self.post_operations()

    # @register_callback
    def pre_operations(self):
        pass

    # @register_callback
    def post_operations(self):
        pass

    def _output(self, *args, **kwargs):
        result = self.deserialize_output(self.ctx.vars.instance.value, client_flatten=True)
        next_link = self.deserialize_output(self.ctx.vars.instance.next_link)
        return result, next_link

    class ClustersListByResourceGroup(AAZHttpOperation):
        CLIENT_TYPE = "MgmtClient"

        def __call__(self, *args, **kwargs):
            request = self.make_request()
            session = self.client.send_request(request=request, stream=False, **kwargs)
            if session.http_response.status_code in [200]:
                return self.on_200(session)

            return self.on_error(session.http_response)

        @property
        def url(self):
            return self.client.format_url(
                "/subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/providers/Microsoft.OperationalInsights/clusters",
                **self.url_parameters
            )

        @property
        def method(self):
            return "GET"

        @property
        def error_format(self):
            return "MgmtErrorFormat"

        @property
        def url_parameters(self):
            parameters = {
                **self.serialize_url_param(
                    "resourceGroupName", self.ctx.args.resource_group,
                    required=True,
                ),
                **self.serialize_url_param(
                    "subscriptionId", self.ctx.subscription_id,
                    required=True,
                ),
            }
            return parameters

        @property
        def query_parameters(self):
            parameters = {
                **self.serialize_query_param(
                    "api-version", "2021-06-01",
                    required=True,
                ),
            }
            return parameters

        @property
        def header_parameters(self):
            parameters = {
                **self.serialize_header_param(
                    "Accept", "application/json",
                ),
            }
            return parameters

        def on_200(self, session):
            data = self.deserialize_http_content(session)
            self.ctx.set_var(
                "instance",
                data,
                schema_builder=self._build_schema_on_200
            )

        _schema_on_200 = None

        @classmethod
        def _build_schema_on_200(cls):
            if cls._schema_on_200 is not None:
                return cls._schema_on_200

            cls._schema_on_200 = AAZObjectType()

            _schema_on_200 = cls._schema_on_200
            _schema_on_200.next_link = AAZStrType(
                serialized_name="nextLink",
            )
            _schema_on_200.value = AAZListType()

            value = cls._schema_on_200.value
            value.Element = AAZObjectType()

            _element = cls._schema_on_200.value.Element
            _element.id = AAZStrType(
                flags={"read_only": True},
            )
            _element.identity = AAZObjectType()
            _element.location = AAZStrType(
                flags={"required": True},
            )
            _element.name = AAZStrType(
                flags={"read_only": True},
            )
            _element.properties = AAZObjectType(
                flags={"client_flatten": True},
            )
            _element.sku = AAZObjectType()
            _element.tags = AAZDictType()
            _element.type = AAZStrType(
                flags={"read_only": True},
            )

            identity = cls._schema_on_200.value.Element.identity
            identity.principal_id = AAZStrType(
                serialized_name="principalId",
                flags={"read_only": True},
            )
            identity.tenant_id = AAZStrType(
                serialized_name="tenantId",
                flags={"read_only": True},
            )
            identity.type = AAZStrType(
                flags={"required": True},
            )
            identity.user_assigned_identities = AAZDictType(
                serialized_name="userAssignedIdentities",
            )

            user_assigned_identities = cls._schema_on_200.value.Element.identity.user_assigned_identities
            user_assigned_identities.Element = AAZObjectType()

            _element = cls._schema_on_200.value.Element.identity.user_assigned_identities.Element
            _element.client_id = AAZStrType(
                serialized_name="clientId",
                flags={"read_only": True},
            )
            _element.principal_id = AAZStrType(
                serialized_name="principalId",
                flags={"read_only": True},
            )

            properties = cls._schema_on_200.value.Element.properties
            properties.associated_workspaces = AAZListType(
                serialized_name="associatedWorkspaces",
                flags={"read_only": True},
            )
            properties.billing_type = AAZStrType(
                serialized_name="billingType",
            )
            properties.capacity_reservation_properties = AAZObjectType(
                serialized_name="capacityReservationProperties",
            )
            properties.cluster_id = AAZStrType(
                serialized_name="clusterId",
                flags={"read_only": True},
            )
            properties.created_date = AAZStrType(
                serialized_name="createdDate",
                flags={"read_only": True},
            )
            properties.is_availability_zones_enabled = AAZBoolType(
                serialized_name="isAvailabilityZonesEnabled",
            )
            properties.key_vault_properties = AAZObjectType(
                serialized_name="keyVaultProperties",
            )
            properties.last_modified_date = AAZStrType(
                serialized_name="lastModifiedDate",
                flags={"read_only": True},
            )
            properties.provisioning_state = AAZStrType(
                serialized_name="provisioningState",
                flags={"read_only": True},
            )

            associated_workspaces = cls._schema_on_200.value.Element.properties.associated_workspaces
            associated_workspaces.Element = AAZObjectType(
                flags={"read_only": True},
            )

            _element = cls._schema_on_200.value.Element.properties.associated_workspaces.Element
            _element.associate_date = AAZStrType(
                serialized_name="associateDate",
                flags={"read_only": True},
            )
            _element.resource_id = AAZStrType(
                serialized_name="resourceId",
                flags={"read_only": True},
            )
            _element.workspace_id = AAZStrType(
                serialized_name="workspaceId",
                flags={"read_only": True},
            )
            _element.workspace_name = AAZStrType(
                serialized_name="workspaceName",
                flags={"read_only": True},
            )

            capacity_reservation_properties = cls._schema_on_200.value.Element.properties.capacity_reservation_properties
            capacity_reservation_properties.last_sku_update = AAZStrType(
                serialized_name="lastSkuUpdate",
                flags={"read_only": True},
            )
            capacity_reservation_properties.min_capacity = AAZIntType(
                serialized_name="minCapacity",
                flags={"read_only": True},
            )

            key_vault_properties = cls._schema_on_200.value.Element.properties.key_vault_properties
            key_vault_properties.key_name = AAZStrType(
                serialized_name="keyName",
            )
            key_vault_properties.key_rsa_size = AAZIntType(
                serialized_name="keyRsaSize",
            )
            key_vault_properties.key_vault_uri = AAZStrType(
                serialized_name="keyVaultUri",
            )
            key_vault_properties.key_version = AAZStrType(
                serialized_name="keyVersion",
            )

            sku = cls._schema_on_200.value.Element.sku
            sku.capacity = AAZIntType()
            sku.name = AAZStrType()

            tags = cls._schema_on_200.value.Element.tags
            tags.Element = AAZStrType()

            return cls._schema_on_200

    class ClustersList(AAZHttpOperation):
        CLIENT_TYPE = "MgmtClient"

        def __call__(self, *args, **kwargs):
            request = self.make_request()
            session = self.client.send_request(request=request, stream=False, **kwargs)
            if session.http_response.status_code in [200]:
                return self.on_200(session)

            return self.on_error(session.http_response)

        @property
        def url(self):
            return self.client.format_url(
                "/subscriptions/{subscriptionId}/providers/Microsoft.OperationalInsights/clusters",
                **self.url_parameters
            )

        @property
        def method(self):
            return "GET"

        @property
        def error_format(self):
            return "MgmtErrorFormat"

        @property
        def url_parameters(self):
            parameters = {
                **self.serialize_url_param(
                    "subscriptionId", self.ctx.subscription_id,
                    required=True,
                ),
            }
            return parameters

        @property
        def query_parameters(self):
            parameters = {
                **self.serialize_query_param(
                    "api-version", "2021-06-01",
                    required=True,
                ),
            }
            return parameters

        @property
        def header_parameters(self):
            parameters = {
                **self.serialize_header_param(
                    "Accept", "application/json",
                ),
            }
            return parameters

        def on_200(self, session):
            data = self.deserialize_http_content(session)
            self.ctx.set_var(
                "instance",
                data,
                schema_builder=self._build_schema_on_200
            )

        _schema_on_200 = None

        @classmethod
        def _build_schema_on_200(cls):
            if cls._schema_on_200 is not None:
                return cls._schema_on_200

            cls._schema_on_200 = AAZObjectType()

            _schema_on_200 = cls._schema_on_200
            _schema_on_200.next_link = AAZStrType(
                serialized_name="nextLink",
            )
            _schema_on_200.value = AAZListType()

            value = cls._schema_on_200.value
            value.Element = AAZObjectType()

            _element = cls._schema_on_200.value.Element
            _element.id = AAZStrType(
                flags={"read_only": True},
            )
            _element.identity = AAZObjectType()
            _element.location = AAZStrType(
                flags={"required": True},
            )
            _element.name = AAZStrType(
                flags={"read_only": True},
            )
            _element.properties = AAZObjectType(
                flags={"client_flatten": True},
            )
            _element.sku = AAZObjectType()
            _element.tags = AAZDictType()
            _element.type = AAZStrType(
                flags={"read_only": True},
            )

            identity = cls._schema_on_200.value.Element.identity
            identity.principal_id = AAZStrType(
                serialized_name="principalId",
                flags={"read_only": True},
            )
            identity.tenant_id = AAZStrType(
                serialized_name="tenantId",
                flags={"read_only": True},
            )
            identity.type = AAZStrType(
                flags={"required": True},
            )
            identity.user_assigned_identities = AAZDictType(
                serialized_name="userAssignedIdentities",
            )

            user_assigned_identities = cls._schema_on_200.value.Element.identity.user_assigned_identities
            user_assigned_identities.Element = AAZObjectType()

            _element = cls._schema_on_200.value.Element.identity.user_assigned_identities.Element
            _element.client_id = AAZStrType(
                serialized_name="clientId",
                flags={"read_only": True},
            )
            _element.principal_id = AAZStrType(
                serialized_name="principalId",
                flags={"read_only": True},
            )

            properties = cls._schema_on_200.value.Element.properties
            properties.associated_workspaces = AAZListType(
                serialized_name="associatedWorkspaces",
                flags={"read_only": True},
            )
            properties.billing_type = AAZStrType(
                serialized_name="billingType",
            )
            properties.capacity_reservation_properties = AAZObjectType(
                serialized_name="capacityReservationProperties",
            )
            properties.cluster_id = AAZStrType(
                serialized_name="clusterId",
                flags={"read_only": True},
            )
            properties.created_date = AAZStrType(
                serialized_name="createdDate",
                flags={"read_only": True},
            )
            properties.is_availability_zones_enabled = AAZBoolType(
                serialized_name="isAvailabilityZonesEnabled",
            )
            properties.key_vault_properties = AAZObjectType(
                serialized_name="keyVaultProperties",
            )
            properties.last_modified_date = AAZStrType(
                serialized_name="lastModifiedDate",
                flags={"read_only": True},
            )
            properties.provisioning_state = AAZStrType(
                serialized_name="provisioningState",
                flags={"read_only": True},
            )

            associated_workspaces = cls._schema_on_200.value.Element.properties.associated_workspaces
            associated_workspaces.Element = AAZObjectType(
                flags={"read_only": True},
            )

            _element = cls._schema_on_200.value.Element.properties.associated_workspaces.Element
            _element.associate_date = AAZStrType(
                serialized_name="associateDate",
                flags={"read_only": True},
            )
            _element.resource_id = AAZStrType(
                serialized_name="resourceId",
                flags={"read_only": True},
            )
            _element.workspace_id = AAZStrType(
                serialized_name="workspaceId",
                flags={"read_only": True},
            )
            _element.workspace_name = AAZStrType(
                serialized_name="workspaceName",
                flags={"read_only": True},
            )

            capacity_reservation_properties = cls._schema_on_200.value.Element.properties.capacity_reservation_properties
            capacity_reservation_properties.last_sku_update = AAZStrType(
                serialized_name="lastSkuUpdate",
                flags={"read_only": True},
            )
            capacity_reservation_properties.min_capacity = AAZIntType(
                serialized_name="minCapacity",
                flags={"read_only": True},
            )

            key_vault_properties = cls._schema_on_200.value.Element.properties.key_vault_properties
            key_vault_properties.key_name = AAZStrType(
                serialized_name="keyName",
            )
            key_vault_properties.key_rsa_size = AAZIntType(
                serialized_name="keyRsaSize",
            )
            key_vault_properties.key_vault_uri = AAZStrType(
                serialized_name="keyVaultUri",
            )
            key_vault_properties.key_version = AAZStrType(
                serialized_name="keyVersion",
            )

            sku = cls._schema_on_200.value.Element.sku
            sku.capacity = AAZIntType()
            sku.name = AAZStrType()

            tags = cls._schema_on_200.value.Element.tags
            tags.Element = AAZStrType()

            return cls._schema_on_200


__all__ = ["List"]



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=too-many-lines
# pylint: disable=too-many-statements


def billing_invoice_download_validator(namespace):
    from azure.cli.core.azclierror import (
        RequiredArgumentMissingError,
        MutuallyExclusiveArgumentError,
    )

    valid_combs = (
        "only --account-name, --invoice-name, --download-token / "
        "--account-name, --download-urls / "
        "--download-urls /"
        "--invoice-name, --download-token is valid"
    )

    if namespace.account_name:
        if namespace.download_token is None and namespace.invoice_name is None and namespace.download_urls is None:
            raise RequiredArgumentMissingError(
                "--download-urls / --download-token, --invoice-name is also required"
            )

        if namespace.download_urls is not None:
            if namespace.download_token is not None or namespace.invoice_name is not None:
                raise MutuallyExclusiveArgumentError(valid_combs)
        if namespace.download_urls is None:
            if namespace.download_token is None and namespace.invoice_name is None:
                raise RequiredArgumentMissingError(
                    "--download-token and --invoice-name are also required"
                )
            if namespace.download_token is None:
                raise RequiredArgumentMissingError("--download-token is also required")
            if namespace.invoice_name is None:
                raise RequiredArgumentMissingError("--invoice-name is also required")

    if namespace.invoice_name is not None:
        if namespace.download_urls is not None:
            raise MutuallyExclusiveArgumentError(valid_combs)
        if namespace.download_token is None:
            raise RequiredArgumentMissingError(
                "--account-name and --download-token are also required"
            )

    if namespace.download_token is not None:
        if namespace.download_urls is not None:
            raise MutuallyExclusiveArgumentError(valid_combs)
        if namespace.account_name is not None and namespace.invoice_name is None:
            raise RequiredArgumentMissingError("--invoice-name is also required")
        if namespace.invoice_name is None:
            raise RequiredArgumentMissingError(
                "--account-name and --invoice-name are also required"
            )

    if namespace.download_urls is not None:
        if namespace.download_token is not None:
            raise MutuallyExclusiveArgumentError(
                "--download-urls can't be used with --download-token"
            )
        if namespace.invoice_name is not None:
            raise MutuallyExclusiveArgumentError(
                "--download-urls can't be used with --invoice-name"
            )


def billing_invoice_show_validator(namespace):
    from azure.cli.core.azclierror import (
        RequiredArgumentMissingError,
        MutuallyExclusiveArgumentError,
    )

    valid_combs = (
        "only --account-name, --name / --name / --name, --by-subscription is valid"
    )

    if namespace.account_name is not None:
        if namespace.by_subscription is not None:
            raise MutuallyExclusiveArgumentError(valid_combs)
        if namespace.name is None:
            raise RequiredArgumentMissingError("--name is also required")

    if namespace.by_subscription is not None:
        if namespace.name is None:
            raise RequiredArgumentMissingError("--name is also required")


def billing_profile_show_validator(namespace):

    from azure.cli.core.azclierror import MutuallyExclusiveArgumentError

    if namespace.profile_name is not None and namespace.customer_name is not None:
        raise MutuallyExclusiveArgumentError(
            "--profile-name can't be used with --customer-name"
        )


def billing_policy_update_validator(namespace):
    from azure.cli.core.azclierror import (
        RequiredArgumentMissingError,
        MutuallyExclusiveArgumentError,
    )

    if namespace.customer_name is not None:
        mutual_exclusive_arguments = (
            namespace.profile_name,
            namespace.marketplace_purchases,
            namespace.reservation_purchases,
        )
        if any(mutual_exclusive_arguments):
            raise MutuallyExclusiveArgumentError(
                "--customer-name can't be used with "
                "--profile-name / --marketplace-purchases / --reservation-purchases"
            )

    if namespace.profile_name is None and namespace.customer_name is None:
        raise RequiredArgumentMissingError(
            "only "
            "--account-name, --profile-name, [--marketplace-purchases, --reservation-purchases, --view-charges] / "
            "--account-name, --customer-name, [--view-charges] "
            "is valid"
        )


def billing_permission_list_validator(namespace):
    from azure.cli.core.azclierror import MutuallyExclusiveArgumentError

    if namespace.customer_name is not None:
        if namespace.invoice_section_name is not None:
            raise MutuallyExclusiveArgumentError(
                "--customer-name can't be used with --invoice-section-name"
            )

        if namespace.profile_name is not None:
            raise MutuallyExclusiveArgumentError(
                "--customer-name can't be used with --profile-name"
            )
